@@ -10,6 +10,15 @@
 #'@family Auxiliary Functions
 #'
 #'@export
+#'@examples
+#'#text embedding is an array of shape (batch,times,features)
+#'example_embedding<-c(1:24)
+#'example_embedding<-array(example_embedding,dim=c(4,3,2))
+#'example_embedding
+#'
+#'#Transform array to a matrix
+#'#matrix has shape (batch,times*features)
+#'array_to_matrix(example_embedding)
 array_to_matrix<-function(text_embedding){
   features=dim(text_embedding)[3]
   times=dim(text_embedding)[2]
@@ -311,7 +320,7 @@ get_coder_metrics<-function(true_values=NULL,
 #'}
 #'@family Auxiliary Functions
 #'@keywords internal
-get_train_test_split<-function(embedding,
+get_train_test_split<-function(embedding=NULL,
                                target,
                                val_size){
   categories=names(table(target))
@@ -325,17 +334,26 @@ get_train_test_split<-function(embedding,
   val_data=target[unlist(val_sampe)]
   train_data=target[setdiff(names(target),names(val_data))]
 
-  val_embeddings=embedding$clone(deep=TRUE)
-  val_embeddings$embeddings=val_embeddings$embeddings[names(val_data),]
-  val_embeddings$embeddings=na.omit(val_embeddings$embeddings)
-  train_embeddings=embedding$clone(deep=TRUE)
-  train_embeddings$embeddings=train_embeddings$embeddings[names(train_data),]
-  train_embeddings$embeddings=na.omit(train_embeddings$embeddings)
+  if(is.null(embedding)==FALSE){
+
+    val_embeddings=embedding$clone(deep=TRUE)
+    val_embeddings$embeddings=val_embeddings$embeddings[names(val_data),]
+    val_embeddings$embeddings=na.omit(val_embeddings$embeddings)
+    train_embeddings=embedding$clone(deep=TRUE)
+    train_embeddings$embeddings=train_embeddings$embeddings[names(train_data),]
+    train_embeddings$embeddings=na.omit(train_embeddings$embeddings)
+
+    results<-list(target_train=train_data,
+                  embeddings_train=train_embeddings,
+                  target_test=val_data,
+                  embeddings_test=val_embeddings)
+  } else {
+    results<-list(target_train=train_data,
+                  embeddings_train=NA,
+                  target_test=val_data,
+                  embeddings_test=NA)
+  }
 
-  results<-list(target_train=train_data,
-                embeddings_train=train_embeddings,
-                target_test=val_data,
-                embeddings_test=val_embeddings)
   return(results)
 }
 
@@ -840,7 +858,7 @@ get_stratified_train_test_split<-function(targets, val_size=0.25){
 #'
 #'Function for calculating the number of chunks/sequences for every case
 #'
-#'@param text_embeddings \code{data.frame} containing the text embeddings.
+#'@param text_embeddings \code{data.frame} or \code{array} containing the text embeddings.
 #'@param features \code{int} Number of features within each sequence.
 #'@param times \code{int} Number of sequences
 #'@return Named\code{vector} of integers representing the number of chunks/sequences
@@ -849,15 +867,41 @@ get_stratified_train_test_split<-function(targets, val_size=0.25){
 #'@family Auxiliary Functions
 #'
 #'@export
+#'@examples
+#'test_array<-array(data=c(1,1,1,0,0,0,0,0,0,
+#'                         2,1,1,2,5,6,0,0,0,
+#'                         1,2,5,6,1,2,0,4,2),
+#'                         dim=c(3,3,3))
+#'test_array
+#'#test array has shape (batch,times,features) with
+#'#times=3 and features=3
+#'
+#'#Slices where all values are zero are padded.
+#'
+#'get_n_chunks(text_embeddings=test_array,features=3,times=3)
+#'#The length of case 1 is 1, case 2 is 3, and case 3 is 2.
 get_n_chunks<-function(text_embeddings,features,times){
   n_chunks<-vector(length = nrow(text_embeddings))
   n_chunks[]<-0
-  for(i in 1:times){
-    window<-c(1:features)+(i-1)*features
-    sub_matrix<-text_embeddings[,window]
-    tmp_sums<-rowSums(abs(sub_matrix))
-    n_chunks<-n_chunks+as.numeric(!tmp_sums==0)
+
+  if(length(dim(text_embeddings))==2){
+    for(i in 1:times){
+      window<-c(1:features)+(i-1)*features
+      sub_matrix<-text_embeddings[,window]
+      tmp_sums<-rowSums(abs(sub_matrix))
+      n_chunks<-n_chunks+as.numeric(!tmp_sums==0)
+    }
+  } else if (length(dim(text_embeddings))==3){
+    for(i in 1:times){
+      sub_matrix<-text_embeddings[,i,]
+      tmp_sums<-rowSums(abs(sub_matrix))
+      n_chunks<-n_chunks+as.numeric(!tmp_sums==0)
+    }
+  } else {
+    stop("Dimensionality of text_embeddings must be 2 (matrix) or 3 (array).")
   }
+
+
   names(n_chunks)<-rownames(text_embeddings)
   return(n_chunks)
 }
@@ -1031,3 +1075,6 @@ is.null_or_na<-function(object){
     return(TRUE)
   }
 }
+
+
+
