@@ -1,4 +1,6 @@
 testthat::skip_on_cran()
+testthat::skip_if_not_installed(pkg="quanteda")
+testthat::skip_if_not_installed(pkg="udpipe")
 
 tmp_path="test_data/language_models/udpipe_models/english-ewt-ud-2.5-191206.udpipe"
 tmp_condition=file.exists(testthat::test_path(tmp_path))
@@ -6,10 +8,7 @@ testthat::skip_if_not(condition=tmp_condition,
                   message = "udpipe language model not available")
 
 test_that("bow_pp_create_vocab_draft", {
-  example_data<-data.frame(
-    id=quanteda::docvars(quanteda.textmodels::data_corpus_moviereviews)$id1,
-    label=quanteda::docvars(quanteda.textmodels::data_corpus_moviereviews)$sentiment)
-  example_data$text<-as.character(quanteda.textmodels::data_corpus_moviereviews)
+  example_data<-imdb_movie_reviews
 
   res<-bow_pp_create_vocab_draft(
     path_language_model=testthat::test_path(tmp_path),
