@@ -14,6 +14,8 @@ set_config_tf_logger("ERROR")
 set_config_os_environ_logger("ERROR")
 transformers$logging$disable_progress_bar()
 
+datasets$disable_progress_bars()
+
 if(dir.exists(testthat::test_path("test_artefacts"))==FALSE){
   dir.create(testthat::test_path("test_artefacts"))
 }
@@ -53,10 +55,7 @@ rows_susatainability["longformer"]=2
 rows_susatainability["deberta_v2"]=3
 
 
-example_data<-data.frame(
-  id=quanteda::docvars(quanteda.textmodels::data_corpus_moviereviews)$id1,
-  label=quanteda::docvars(quanteda.textmodels::data_corpus_moviereviews)$sentiment)
-example_data$text<-as.character(quanteda.textmodels::data_corpus_moviereviews)
+example_data<-imdb_movie_reviews
 
 print(check_aif_py_modules())
 
